package java.awt;

import java.beans.Transient;
import java.io.Serializable;
import java.awt.geom.Dimension2D;

public class Dimension extends Dimension2D implements Serializable
{
    public int width;
    public int height;
    private static final long serialVersionUID = 4723952579491349524L;
    
    private static native void initIDs();
    
    public Dimension() {
        this(0, 0);
    }
    
    public Dimension(Dimension dimension) {
        this(dimension.width, dimension.height);
    }
    
    public Dimension(int width, int height) {
        this.width = width;
        this.height = height;
    }
    
    @Override
    public double getWidth() {
        return (double)this.width;
    }
    
    @Override
    public double getHeight() {
        return (double)this.height;
    }
    
    @Override
    public void setSize(double a, double a2) {
        this.width = (int)Math.ceil(a);
        this.height = (int)Math.ceil(a2);
    }
    
    @Transient
    public Dimension getSize() {
        return new Dimension(this.width, this.height);
    }
    
    public void setSize(Dimension dimension) {
        this.setSize(dimension.width, dimension.height);
    }
    
    public void setSize(int width, int height) {
        this.width = width;
        this.height = height;
    }
    
    @Override
    public boolean equals(Object o) {
        if ((o instanceof Dimension)) {
            Dimension dimension = (Dimension)o;
            return this.width == dimension.width && this.height == dimension.height;
        }
        return false;
    }
    
    @Override
    public int hashCode() {
        int n = this.width + this.height;
        return n * (n + 1) / 2 + this.width;
    }
    
    @Override
    public String toString() {
        return this.getClass().getName() + "[width=" + this.width + ",height=" + this.height + "]";
    }
    
    static {
        Toolkit.loadLibraries();
        if (!GraphicsEnvironment.isHeadless()) {
            initIDs();
        }
    }
}
